@@ -1,5 +1,6 @@
 import logging
 
+import time
 from abc import ABC, abstractmethod
 from aiohttp import ClientSession, ClientResponse, ClientError
 
@@ -9,6 +10,13 @@ from .const import CA_TEMP_RANGE
 _LOGGER = logging.getLogger(__name__)
 
 
+def convert_set_temp_to_api_from_celsius_value(set_temp):
+    set_temp = CA_TEMP_RANGE.index(set_temp)
+    set_temp = hex(set_temp).split("x")
+    set_temp = set_temp[1] + "H"
+    return set_temp.zfill(3).upper()
+
+
 def request_with_logging_and_errors_raised(func):
     async def request_with_logging_wrapper(*args, **kwargs):
         url = kwargs["url"]
@@ -24,6 +32,7 @@ def request_with_logging_and_errors_raised(func):
         response_json = await response.json()
         if response_json["responseHeader"]["responseCode"] == 0:
             return response
+        # still need to add error code for expired token
         if response_json["error"]["errorCode"] == 7404:
             _LOGGER.debug(f"invalid password")
             raise AuthError(response_json["error"]["errorDesc"])
@@ -71,7 +80,7 @@ class Ca(ABC):
             "referer": "https://" + self.base_url + "/login",
             "from": "SPA",
             "language": "0",
-            "offset": "0",
+            "offset": str(int(time.localtime().tm_gmtoff / 60 / 60)),
             "sec-fetch-dest": "empty",
             "sec-fetch-mode": "cors",
             "sec-fetch-site": "same-origin",
@@ -144,7 +153,7 @@ class Ca(ABC):
         response_json = await response.json()
         return response_json["result"]
 
-    async def get_pin_token(self, access_token: str, pin: str) -> str:
+    async def get_pin_token(self, access_token: str, pin: str) -> dict[str, any]:
         url = self.api_url + "vrfypin"
         json_body = {"pin": pin}
         response = await self._post_request_with_logging_and_errors_raised(
@@ -240,11 +249,6 @@ class Ca(ABC):
     ):
         url = self.api_url + "rmtstrt"
 
-        set_temp = CA_TEMP_RANGE.index(set_temp)
-        set_temp = hex(set_temp).split("x")
-        set_temp = set_temp[1] + "H"
-        set_temp = set_temp.zfill(3).upper()
-
         json_body = {
             "setting": {
                 "airCtrl": int(climate),
@@ -252,7 +256,7 @@ class Ca(ABC):
                 "heating1": int(heating),
                 "igniOnDuration": duration,
                 "ims": 0,
-                "airTemp": {"value": set_temp, "unit": 0, "hvacTempType": 0},
+                "airTemp": {"value": convert_set_temp_to_api_from_celsius_value(set_temp), "unit": 0, "hvacTempType": 0},
             },
             "pin": pin,
         }
@@ -279,18 +283,13 @@ class Ca(ABC):
     ):
         url = self.api_url + "evc/rfon"
 
-        set_temp = CA_TEMP_RANGE.index(set_temp)
-        set_temp = hex(set_temp).split("x")
-        set_temp = set_temp[1] + "H"
-        set_temp = set_temp.zfill(3).upper()
-
         json_body = {
             "hvacInfo": {
                 "airCtrl": int(climate),
                 "defrost": defrost,
                 "heating1": int(heating),
                 "airTemp": {
-                    "value": set_temp,
+                    "value": convert_set_temp_to_api_from_celsius_value(set_temp),
                     "unit": 0,
                     "hvacTempType": 1,
                 },
